api.world.v1 package — Argus-Toolbelt 1.0 documentation

# api.world.v1 package

## Submodules

## api.world.v1.timezone module

Autogenerated API

`api.world.v1.timezone.` `get_time_zones`(keywords: list = None, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get all time zones (PUBLIC)

  Return type: | `dict`
  Parameters: | keywords (list) – Filter time zones by keywords offset (int) – Skip a number of time zones limit (int) – Maximum number of returned time zones
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 764, “limit”: 543, “responseCode”: 200, “count”: 247, “data”: [{“description”: “Work spring national friend wear him staff.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Study something car north fight action.”, “messageTemplate”: “Serious drop rate off instead.”, “field”: “Class create scene might role space foreign.”, “parameter”: {}, “timestamp”: 1239705835}], “currentPage”: 100, “size”: 385}

## Module contents